//
//  AliyunPlaySDKDemoOneViewController.m
//  AliyunPlayerMediaDemo
//
//  Created by 王凯 on 2017/8/14.
//  Copyright © 2017年 com.alibaba.ALPlayerVodSDK. All rights reserved.
//

#import "AliyunPlaySDKDemoOneViewController.h"
#import <AliyunVodPlayerSDK/AliyunVodPlayer.h>
#import <MediaPlayer/MediaPlayer.h>
#import "AliyunPlayMessageShowView.h"
#import "ALiyunPlaySDKCheckToolViewController.h"
#import "UIView+Layout.h"

#define SCREEN_WIDTH  [UIScreen mainScreen].bounds.size.width
#define SCREEN_HEIGHT [UIScreen mainScreen].bounds.size.height
#define BUTTONTAG  5001

static BOOL s_autoPlay = NO;


@interface AliyunPlaySDKDemoOneViewController ()<AliyunVodPlayerDelegate>
{
    //代表进度条是否可以更新
    BOOL  mProgressCanUpdate;
    NSString* mVid;
    NSString* mPlayAuth;
}
/*
 *集成所需配置
 */
@property(nonatomic ,strong)UIView *playerBackgroundView;
@property(nonatomic ,strong)UIView *playerView;
@property(nonatomic ,strong)AliyunVodPlayer *aliPlayer;
//计时器，时时获取currentTime
@property (nonatomic, strong) NSTimer *timer;

/*
 *以下属性为 界面元素部署,
 */
@property (weak, nonatomic) IBOutlet UIView *playerContentView;
@property (weak, nonatomic) IBOutlet NSLayoutConstraint *viewHeight;
@property (weak, nonatomic) IBOutlet UILabel *leftTimeLabel;
@property (weak, nonatomic) IBOutlet UILabel *rightTimeLabel;
@property (weak, nonatomic) IBOutlet UISlider *timeProgress;
@property (weak, nonatomic) IBOutlet UIButton *qualitysButton;
@property (weak, nonatomic) IBOutlet UIView *scrollviewContentView;
@property (weak, nonatomic) IBOutlet UISwitch *autoSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *muteSwitch;
@property (weak, nonatomic) IBOutlet UISegmentedControl *disPlayModeSegment;
@property (nonatomic, strong)AliyunPlayMessageShowView * showMessageView;

@property (nonatomic, strong)ALPlayerVideoErrorModel *tempErrorModel;
@property (nonatomic, strong)NSMutableArray *qualitysAry;

@end

@implementation AliyunPlaySDKDemoOneViewController

#pragma mark - scrollview
- (void)updateViewConstraints{
    [super updateViewConstraints];
    self.viewHeight.constant = CGRectGetHeight([UIScreen mainScreen].bounds)*2;
}

#pragma mark - 播放器初始化
-(AliyunVodPlayer *)aliPlayer{
    if (!_aliPlayer) {
        _aliPlayer = [[AliyunVodPlayer alloc] init];
        _aliPlayer.delegate = self;
        [self.aliPlayer setAutoPlay:s_autoPlay];
        
        NSArray *pathArray = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
        NSString *docDir = [pathArray objectAtIndex:0];
        //maxsize mb    maxDuration 秒
        [_aliPlayer setPlayingCache:NO saveDir:docDir maxSize:30 maxDuration:10000];
        
    }
    return _aliPlayer;
}

#pragma mark - 懒加载
-(UIView *)playerBackgroundView{
    if (!_playerBackgroundView) {
        _playerBackgroundView = [[UIView alloc] init];
        _playerBackgroundView.backgroundColor = [UIColor clearColor];
    }
    return  _playerBackgroundView;
}

- (UIView *)playerView{
    if (!_playerView) {
        _playerView = [[UIView alloc] init];
    }
    return  _playerView;
}

#pragma  mark - initView
- (void)initView{
    /***********播放器界面搭建**************/
    self.playerView = self.aliPlayer.playerView;
    [self.playerContentView addSubview:self.playerView];
    
    
    [self.view setBackgroundColor:[UIColor whiteColor]];
    self.leftTimeLabel.textColor = [UIColor blueColor];
    self.rightTimeLabel.textColor = [UIColor blueColor];
    [self.playerContentView bringSubviewToFront:self.leftTimeLabel];
    [self.playerContentView bringSubviewToFront:self.rightTimeLabel];
    [self.playerContentView bringSubviewToFront:self.timeProgress];
    
    
    self.showMessageView.hidden = YES;
    [self.view addSubview:self.showMessageView];
}


-(void)setPlaySource:(NSString*)vid playAuth:(NSString*)playAuth
{
    mVid = vid;
    mPlayAuth = playAuth;
}

#pragma mark - naviBar
- (void)InitNaviBar{
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"返回" style:UIBarButtonItemStylePlain target:self action:@selector(returnButtonItemCliceked:)];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"日志" style:UIBarButtonItemStylePlain target:self action:@selector(LogButtonItemCliceked:)];
}

- (void)returnButtonItemCliceked:(UIBarButtonItem*)sender{
    [self.aliPlayer stop];
    [self.aliPlayer releasePlayer];
    self.aliPlayer = nil;
    if (self.timer) {
        [self.timer invalidate];
        self.timer = nil;
    }
    [self.navigationController popViewControllerAnimated:YES];
}

#pragma mark - 展示log界面
-(AliyunPlayMessageShowView *)showMessageView{
    if (!_showMessageView){
        _showMessageView = [[AliyunPlayMessageShowView alloc] init];
        _showMessageView.backgroundColor = [UIColor colorWithWhite:0.5 alpha:0.8];
        _showMessageView.alpha = 1;
    }
    
    return _showMessageView;
}

- (void)LogButtonItemCliceked:(UIBarButtonItem*)sender{
    self.showMessageView.hidden = NO;
}

#pragma  mark - 点击切换清晰度按钮
-(void)qualityChanged:(UISegmentedControl *)Seg{
    NSInteger Index = Seg.selectedSegmentIndex;
    if (_qualitysAry.count == 0) {
        return;
    }
    NSString* strQuality = _qualitysAry[Index];
    [self.aliPlayer setQuality:(AliyunVodPlayerVideoQuality)[strQuality intValue]];
}

#pragma mark - viewDidLoad
- (void)viewDidLoad {
    [super viewDidLoad];
    _qualitysAry = [[NSMutableArray alloc] init];
    self.edgesForExtendedLayout = UIRectEdgeNone;
    [self InitNaviBar];
    [self.autoSwitch setOn:s_autoPlay];
    [self.disPlayModeSegment setSelectedSegmentIndex:self.aliPlayer.displayMode];
    [self.muteSwitch setOn:self.aliPlayer.muteMode];
    [_qualityControl addTarget:self action:@selector(qualityChanged:) forControlEvents:UIControlEventValueChanged];
    //sdk版本号
    NSString *version =  [self.aliPlayer getSDKVersion];
    NSLog(@"%@",version);
    [self.aliPlayer prepareWithVid:mVid playAuth:mPlayAuth];
}


- (void)viewDidLayoutSubviews{
    [super viewDidLayoutSubviews];
    
    
}

- (void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    [self initView];
    mProgressCanUpdate = YES;
}

- (void)viewWillLayoutSubviews{
    [super viewWillLayoutSubviews];
    //storyboard 刷新布局
    self.playerView.frame= CGRectMake(0, 0, self.playerContentView.bounds.size.width, self.playerContentView.bounds.size.height);
    self.showMessageView.frame = self.view.bounds;
}

-(NSString*) videoQualityToString:(NSString*)strQuality
{
    int nQuality = [strQuality intValue];
    AliyunVodPlayerVideoQuality quality = (AliyunVodPlayerVideoQuality)nQuality;
    NSString* strQualityDescrp = @"标清";
    switch (quality) {
        case AliyunVodPlayerVideoFD:
            strQualityDescrp = @"流畅";
            break;
        case AliyunVodPlayerVideoLD:
            strQualityDescrp = @"标清";
            break;
        case AliyunVodPlayerVideoSD:
            strQualityDescrp = @"高清";
            break;
        case AliyunVodPlayerVideoHD:
            strQualityDescrp = @"超清";
            break;
        case AliyunVodPlayerVideo2K:
            strQualityDescrp = @"2K";
            break;
        case AliyunVodPlayerVideo4K:
            strQualityDescrp = @"4K";
            break;
        case AliyunVodPlayerVideoOD:
            strQualityDescrp = @"原画";
            break;
        default:
            break;
    }
    return strQualityDescrp;
}

#pragma mark - AliyunVodPlayerManagerDelegate
- (void)vodPlayer:(AliyunVodPlayer *)vodPlayer onEventCallback:(AliyunVodPlayerEvent)event{
    //清晰度
    if (event == AliyunVodPlayerEventPrepareDone) {
        AliyunVodPlayerVideo *videoModel = [self.aliPlayer getAliyunMediaInfo];
        self.rightTimeLabel.text = [self getMMSSFromSS:[NSString stringWithFormat:@"%.f",videoModel.duration]];
        [_qualitysAry removeAllObjects];
        [_qualityControl removeAllSegments];
        for (NSString* quality in videoModel.allSupportQualitys) {
            NSString* qualityDescription = [self videoQualityToString:quality];
            int index = (int)[_qualityControl numberOfSegments];
            [_qualityControl insertSegmentWithTitle:qualityDescription atIndex:index animated:TRUE];
            if ([quality intValue] == (int)videoModel.videoQuality) {
                [_qualityControl setSelectedSegmentIndex:[_qualityControl numberOfSegments]-1];
            }
            [_qualitysAry addObject:quality];
        }
        [self.timer invalidate];
        self.timer = [NSTimer scheduledTimerWithTimeInterval:1 target:self selector:@selector(timerRun:) userInfo:nil repeats:YES];
        [[NSRunLoop currentRunLoop] addTimer:self.timer forMode:NSDefaultRunLoopMode];
    }
    //增加log展示内容
    [self.showMessageView addTextString:[self getMessageWithevent:event errorMsg:nil] ];
}

- (void)vodPlayer:(AliyunVodPlayer *)vodPlayer playBackErrorModel:(ALPlayerVideoErrorModel *)errorModel{
    mProgressCanUpdate = YES;
    NSString* errDescription = [self getMessageWithevent:errorModel.errorCode errorMsg:errorModel.errorMsg];
    [self.showMessageView addTextString:errDescription];
    self.tempErrorModel = errorModel;
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"错误" message:errDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alert show];
}

- (void)vodPlayer:(AliyunVodPlayer*)vodPlayer willSwitchToQuality:(AliyunVodPlayerVideoQuality)quality{
    mProgressCanUpdate = NO;
}

- (void)vodPlayer:(AliyunVodPlayer *)vodPlayer didSwitchToQuality:(AliyunVodPlayerVideoQuality)quality{
    mProgressCanUpdate = YES;
}

- (void)vodPlayer:(AliyunVodPlayer*)vodPlayer failSwitchToQuality:(AliyunVodPlayerVideoQuality)quality{
}

#pragma mark - 控件事件
- (IBAction)switchChanged:(UISwitch *)sender {
    
    switch (sender.tag) {
        case 301: //自动播放
        {
            [self.aliPlayer setAutoPlay:sender.isOn];
            s_autoPlay = sender.isOn;
        }
            break;
            
        case 302: //静音
        {
            [self.aliPlayer setMuteMode:sender.isOn];
        }
            break;
            
        default:
            break;
    }
}

#pragma mark - seek
- (IBAction)timeProgress:(UISlider *)sender {
    if (self.aliPlayer && (self.aliPlayer.playerState == AliyunVodPlayerStateLoading || self.aliPlayer.playerState == AliyunVodPlayerStatePause ||
        self.aliPlayer.playerState == AliyunVodPlayerStatePlay)) {
        mProgressCanUpdate = NO;
        [ self.aliPlayer seekToTime:sender.value * self.aliPlayer.duration ];
    }
}

#pragma mark - 亮度／音量
- (IBAction)progressChanged:(UISlider *)sender {
    
    //401 音量。 402 亮度
    switch (sender.tag) {
        case 401:
            [self.aliPlayer setVolume:sender.value];
            break;
        case 402:
            [self.aliPlayer setBrightness:sender.value];
            break;
            
        default:
            break;
    }
}

#pragma mark - 显示模式设置
- (IBAction)segmentedControlChanged:(UISegmentedControl *)sender {
    
    [self.aliPlayer setDisplayMode:(int)sender.selectedSegmentIndex];
    
    switch (sender.selectedSegmentIndex) {
        case 0:
            [self.aliPlayer setDisplayMode:AliyunVodPlayerDisplayModeFit];
            break;
        case 1:
            [self.aliPlayer setDisplayMode:AliyunVodPlayerDisplayModeFitWithCropping];
            break;
        default:
            break;
    }
    
}

#pragma mark - play stop pause pause replay
- (IBAction)buttonClicked:(UIButton *)sender {
    switch (sender.tag) {
        case 201://播放
        {
            if (self.aliPlayer.playerState == AliyunVodPlayerStateIdle || self.aliPlayer.playerState == AliyunVodPlayerStateStop) {
                self.aliPlayer.autoPlay = YES;
                [self.aliPlayer prepareWithVid:mVid playAuth:mPlayAuth];
            }
            else {
                [self.aliPlayer start];
                [self.aliPlayer seekToTime:50];
                
            }
        }break;
            
        case 202://停止
        {
            [self.aliPlayer stop];
            [self.timer invalidate];
            [self.timeProgress setValue:0];
            self.leftTimeLabel.text = [self getMMSSFromSS:[NSString stringWithFormat:@"%.f",0.0]];
            
        }break;
            
        case 203://暂停
        {
            [self.aliPlayer pause];
        }break;
            
        case 204://继续
        {
            [self.aliPlayer resume];
        }break;
            
        case 205://重播
        {
            [self.aliPlayer setDisplayMode:(int)self.disPlayModeSegment.selectedSegmentIndex];
            [self.disPlayModeSegment setSelectedSegmentIndex:self.aliPlayer.displayMode];
            [self.aliPlayer replay];
        }break;
            
        case 206 : //诊断
        {
            ALiyunPlaySDKCheckToolViewController *toolVC = [[ALiyunPlaySDKCheckToolViewController alloc] init];
            toolVC.playUrlPath = self.tempErrorModel.errorUrl;
            [self.navigationController pushViewController:toolVC animated:YES];
        }break;
            
        default:
            break;
    }
}


#pragma mark - timerRun
- (void)timerRun:(NSTimer *)sender{
    if (self.aliPlayer && mProgressCanUpdate == YES) {
        self.leftTimeLabel.text = [self getMMSSFromSS:[NSString stringWithFormat:@"%.f",self.aliPlayer.currentTime]];
        [self.timeProgress setValue:self.aliPlayer.currentTime/self.aliPlayer.duration animated:YES];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - 展示内容，不需要关注
- (NSString *)getMessageWithevent:(AliyunVodPlayerEvent)event errorMsg : (NSString *)errorMsg{
    NSString *str = @"";
    switch (event) {
        case AliyunVodPlayerEventPlay:
            str = @"开始播放";
            break;
        case AliyunVodPlayerEventPause:
            str = @"播放器暂停";
            break;
        case AliyunVodPlayerEventStop:
            str = @"播放器停止";
            break;
        case AliyunVodPlayerEventFinish:
            str = @"播放视频完成";
            break;
        case AliyunVodPlayerEventBeginLoading:
            str = @"开始加载视频";
            break;
        case AliyunVodPlayerEventEndLoading:
            str = @"加载视频完成";
            break;
        case AliyunVodPlayerEventPrepareDone :
            str = @"获取到播放数据";
            break;
        case AliyunVodPlayerEventSeekDone :
            str = @"视频跳转seek结束";
            mProgressCanUpdate = YES;
            break;
        case AliyunVodPlayerEventFirstFrame :
            str = @"视频首帧开始播放";
            break;
        default:
            str = [NSString stringWithFormat:@"播放器报错!!! 错误码: %d 错误描述:%@",event,errorMsg];;
            break;
    }
    return str;
}

-(NSString *)getMMSSFromSS:(NSString *)totalTime{
    NSInteger seconds = [totalTime integerValue];
    //format of hour
    NSString *str_hour = [NSString stringWithFormat:@"%02ld",seconds/3600];
    //format of minute
    NSString *str_minute = [NSString stringWithFormat:@"%02ld",(seconds%3600)/60];
    //format of second
    NSString *str_second = [NSString stringWithFormat:@"%02ld",seconds%60];
    //format of time
    NSString *format_time = [NSString stringWithFormat:@"%@:%@:%@",str_hour,str_minute,str_second];
    return format_time;
}


@end
